Crate spinne_core

Crate spinne_core 

Structs

ComponentGraph
A simple graph where nodes are components identified by a unique value, and edges represent the relationship “uses.”
Config
Represents the config file
ConsumerProject
A project that depends on other projects
PackageJson
Handles interactions with package.json
ProjectResolver
SourceProject
A project that is used as a dependency by other projects
Workspace
Represents a workspace containing multiple projects. A workspace is a directory that contains multiple projects and holds a shared component registry

Traits

Project
Trait defining common functionality for all project types