Structs
- ComponentGraph is a graph of components and their relationships. Components are nodes and relationships are edges.
- Handles interactions with package.json
- Represents a project and its components. A Project is typically a repository with a package.json file.
Functions
- resolve a relative file path to an absolute file path